@@ -74,9 +74,9 @@ class Route(object):
         node.handler = handler
 
     def match(self, routes: deque, r: HttpRequest):
-        matched = None
-        node = self
-        mylist = list(routes)
+        matched: str = None
+        deviation_point: Route = None
+        node: Route = self
         while routes:
             route = routes.popleft()
             current_node = node.children.get(route)
@@ -84,18 +84,34 @@ class Route(object):
                 # is there a parameterized child?
                 current_node = node.children.get(':')
                 if current_node:
-                    # what to do here
+                    # if r.params already registered should we throw an error or let them be lol...
+                    # Assume adults are in the room and leave it
                     r.params = current_node.parameterized, route
+
+                    # add a deviation point if the node also has a wildcard route and not already set
+                    # this could be easily tweaked to match last or first encounter but left as is
+                    deviation_point = node.children.get('*', deviation_point)
                     node = current_node
                     continue
 
-                # is there a wild card child? the minute a wildcard is seen all bets are off and children make no sense after it
+                # is there a wild card child at the same level as :? Weird but hey its possible.
+                # the minute a wildcard is seen all bets are off and children make no sense after it
                 wildcard = node.children.get('*')
                 if wildcard:
-                    return wild_card.route, wild_card.handler
+                    print(wildcard.route, ' was actually seen?')
+                    return wildcard.route, wildcard.handler
+
+                # also need to use deviation point here as it is possible for nested match to
+                # bring us here without exiting early from above
+                if deviation_point:
+                    return deviation_point.route, deviation_point.handler
 
                 return matched, self.not_found
             node = current_node
+                
+        # was there a wildcard encountered along the way
+        if deviation_point and not node.route:
+            return deviation_point.route, deviation_point.handler
         return node.route, node.handler
     
     def not_found(self, r: HttpRequest, w: ResponseWriter, c: Context):
@@ -224,7 +240,7 @@ class Routes(object):
 
             # call request handler
             if w._abort: raise AbortException
-            if iscoroutinefunction(handler): await handler(r, w, context)
+            if iscoroutinefunction(handler): await handler(r, w, c)
             else: handler(r, w, c)
 
             # call all post handle request hooks
